/*
 * Copyright (C) 2021 Anton Romanov - All Rights Reserved
 * You may use, distribute and modify this code, please write to: romanov73@gmail.com.
 *
 */

package ru.ulstu.service;

import org.springframework.stereotype.Service;
import ru.ulstu.datamodel.ModelingResult;
import ru.ulstu.datamodel.exception.ModelingException;
import ru.ulstu.datamodel.ts.TimeSeries;
import ru.ulstu.method.Method;

import java.lang.reflect.InvocationTargetException;
import java.util.List;
import java.util.concurrent.ExecutionException;


@Service
public class TimeSeriesService {
    private final MethodParamBruteForce methodParamBruteForce;

    public TimeSeriesService(MethodParamBruteForce methodParamBruteForce) {
        this.methodParamBruteForce = methodParamBruteForce;
    }

    public ModelingResult getForecast(TimeSeries timeSeries, int countPoints) throws ExecutionException, InterruptedException, InvocationTargetException, NoSuchMethodException, InstantiationException, IllegalAccessException, ModelingException {
        return methodParamBruteForce.getForecast(timeSeries, countPoints);
    }

    public ModelingResult smoothTimeSeries(TimeSeries timeSeries) throws ExecutionException, InterruptedException, InvocationTargetException, NoSuchMethodException, InstantiationException, IllegalAccessException {
        return methodParamBruteForce.getSmoothedTimeSeries(timeSeries);
    }

    public List<Method> getAvailableMethods() {
        return methodParamBruteForce.getAvailableMethods();
    }
}
